@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """test_skbuild
 ----------------------------------
@@ -10,6 +9,7 @@ Tests for `skbuild` module.
 import os
 import platform
 import sys
+from shutil import which
 
 import pytest
 
@@ -18,11 +18,10 @@ from skbuild.exceptions import SKBuildError
 from skbuild.platform_specifics import get_platform
 from skbuild.platform_specifics.windows import VS_YEAR_TO_VERSION, find_visual_studio
 
-from . import get_cmakecache_variables, project_setup_py_test, push_dir, push_env, which
+from . import get_cmakecache_variables, project_setup_py_test, push_dir, push_env
 
 
 def test_generator_selection():
-    version = sys.version_info
     env_generator = os.environ.get("CMAKE_GENERATOR")
     this_platform = platform.system().lower()
     get_best_generator = get_platform().get_best_generator
@@ -32,39 +31,16 @@ def test_generator_selection():
         assert get_best_generator(env_generator).name == env_generator
 
     if this_platform == "windows":
-        # assert that we are running a supported version of python
-        py_27_32 = (version.major == 2 and version.minor >= 7) or (version.major == 3 and version.minor <= 2)
-
-        py_33_34 = version.major == 3 and (3 <= version.minor <= 4)
-
-        py_35 = version.major == 3 and version.minor >= 5
-
-        assert len(tuple(filter(bool, (py_27_32, py_33_34, py_35)))) == 1
-
         # Expected Visual Studio version
-        if py_27_32:
-            vs_generator = "Visual Studio 9 2008"
-            vs_version = 9
-        elif py_33_34:
-            vs_generator = "Visual Studio 10 2010"
-            vs_version = 10
-        else:
-            vs_generator = "Visual Studio 14 2015"
-            vs_version = 14
+        vs_generator = "Visual Studio 15 2017"
+        vs_version = 15
+
         vs_generator += " Win64" if arch == "64bit" else ""
 
         has_vs_2017 = find_visual_studio(vs_version=VS_YEAR_TO_VERSION["2017"])
         has_vs_2019 = find_visual_studio(vs_version=VS_YEAR_TO_VERSION["2019"])
         has_vs_2022 = find_visual_studio(vs_version=VS_YEAR_TO_VERSION["2022"])
 
-        # Apply to VS <= 14 (2015)
-        has_vs_ide_vcvars = any(
-            [
-                os.path.exists(path_pattern % vs_version)
-                for path_pattern in ["C:/Program Files (x86)/Microsoft Visual Studio %.1f/VC/vcvarsall.bat"]
-            ]
-        )
-
         # As of Dec 2016, this is available only for VS 9.0
         has_vs_for_python_vcvars = any(
             [
@@ -77,7 +53,7 @@ def test_generator_selection():
         )
 
         # If environment exists, update the expected generator
-        if (has_vs_for_python_vcvars or has_vs_ide_vcvars) and which("ninja.exe"):
+        if has_vs_for_python_vcvars and which("ninja.exe"):
             assert get_best_generator().name == "Ninja"
 
         elif has_vs_2017:
@@ -90,9 +66,6 @@ def test_generator_selection():
             # C:/Program Files (x86)/Microsoft Visual Studio/2017/Professional/Common7/IDE/CommonExtensions/Microsoft/CMake/Ninja/ninja.exe  # noqa: E501
             assert get_best_generator().name == "Ninja"
 
-        elif has_vs_ide_vcvars:
-            assert get_best_generator().name == vs_generator
-
         elif has_vs_for_python_vcvars:
             assert get_best_generator().name == "NMake Makefiles"
 
@@ -109,7 +82,7 @@ def test_generator(generator, expected_make_program):
 
     this_platform = platform.system().lower()
     if this_platform not in generator_platform[generator]:
-        pytest.skip("{} generator is available only on {}".format(generator, this_platform.title()))
+        pytest.skip(f"{generator} generator is available only on {this_platform.title()}")
 
     @project_setup_py_test("hello-cpp", ["build"])
     def run_build():
@@ -154,7 +127,7 @@ def test_invalid_generator(generator_args):
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Requires Windows")
-@pytest.mark.parametrize("vs_year", ["2008", "2010", "2012", "2013", "2015", "2017", "2019", "2022"])
+@pytest.mark.parametrize("vs_year", ["2015", "2017", "2019", "2022"])
 def test_platform_windows_find_visual_studio(vs_year):
     """If the environment variable ``SKBUILD_TEST_FIND_VS<vs_year>_INSTALLATION_EXPECTED`` is set,
     this test asserts the value returned by :func:`skbuild.platforms.windows.find_visual_studio()`.
@@ -175,11 +148,8 @@ def test_platform_windows_find_visual_studio(vs_year):
         assert vs_path == ""
 
 
-@pytest.mark.skipif(sys.version_info < (3, 5), reason="Python 3.5+ required on Windows")
 @pytest.mark.skipif(sys.platform != "win32", reason="Requires Windows")
 def test_toolset():
-    py_35 = sys.version_info[:2] == (3, 5)
-
     has_vs_2017 = find_visual_studio(vs_version=VS_YEAR_TO_VERSION["2017"])
     if not has_vs_2017:
         pytest.skip("Visual Studio 15 2017 is not found")
@@ -205,7 +175,4 @@ def test_toolset():
     var_toolset = variables["CMAKE_GENERATOR_TOOLSET"]
     toolset = var_toolset[1]
 
-    if py_35:
-        assert toolset == "v140"
-    else:
-        assert toolset == "v141"
+    assert toolset == "v141"
